summaryrefslogtreecommitdiff
path: root/src/exchange/taler-exchange-httpd_db.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/exchange/taler-exchange-httpd_db.c')
-rw-r--r--src/exchange/taler-exchange-httpd_db.c36
1 files changed, 18 insertions, 18 deletions
diff --git a/src/exchange/taler-exchange-httpd_db.c b/src/exchange/taler-exchange-httpd_db.c
index 238112771..99ebacf83 100644
--- a/src/exchange/taler-exchange-httpd_db.c
+++ b/src/exchange/taler-exchange-httpd_db.c
@@ -236,7 +236,7 @@ TEH_DB_execute_deposit (struct MHD_Connection *connection,
return TEH_RESPONSE_reply_deposit_success (connection,
&deposit->coin.coin_pub,
&deposit->h_wire,
- &deposit->h_contract,
+ &deposit->h_proposal_data,
deposit->transaction_id,
deposit->timestamp,
deposit->refund_deadline,
@@ -312,7 +312,7 @@ TEH_DB_execute_deposit (struct MHD_Connection *connection,
return TEH_RESPONSE_reply_deposit_success (connection,
&deposit->coin.coin_pub,
&deposit->h_wire,
- &deposit->h_contract,
+ &deposit->h_proposal_data,
deposit->transaction_id,
deposit->timestamp,
deposit->refund_deadline,
@@ -381,8 +381,8 @@ TEH_DB_execute_refund (struct MHD_Connection *connection,
if ( (0 == memcmp (&dep->merchant_pub,
&refund->merchant_pub,
sizeof (struct TALER_MerchantPublicKeyP))) &&
- (0 == memcmp (&dep->h_contract,
- &refund->h_contract,
+ (0 == memcmp (&dep->h_proposal_data,
+ &refund->h_proposal_data,
sizeof (struct GNUNET_HashCode))) &&
(dep->transaction_id == refund->transaction_id) )
{
@@ -402,8 +402,8 @@ TEH_DB_execute_refund (struct MHD_Connection *connection,
if ( (0 == memcmp (&ref->merchant_pub,
&refund->merchant_pub,
sizeof (struct TALER_MerchantPublicKeyP))) &&
- (0 == memcmp (&ref->h_contract,
- &refund->h_contract,
+ (0 == memcmp (&ref->h_proposal_data,
+ &refund->h_proposal_data,
sizeof (struct GNUNET_HashCode))) &&
(ref->transaction_id == refund->transaction_id) &&
(ref->rtransaction_id == refund->rtransaction_id) )
@@ -415,8 +415,8 @@ TEH_DB_execute_refund (struct MHD_Connection *connection,
if ( (0 == memcmp (&ref->merchant_pub,
&refund->merchant_pub,
sizeof (struct TALER_MerchantPublicKeyP))) &&
- (0 == memcmp (&ref->h_contract,
- &refund->h_contract,
+ (0 == memcmp (&ref->h_proposal_data,
+ &refund->h_proposal_data,
sizeof (struct GNUNET_HashCode))) &&
(ref->transaction_id == refund->transaction_id) &&
(ref->rtransaction_id != refund->rtransaction_id) )
@@ -1915,7 +1915,7 @@ struct WtidTransactionContext
* @param merchant_pub public key of the merchant (should be same for all callbacks with the same @e cls)
* @param h_wire hash of wire transfer details of the merchant (should be same for all callbacks with the same @e cls)
* @param exec_time execution time of the wire transfer (should be same for all callbacks with the same @e cls)
* @param h_contract which contract was this payment about
* @param transaction_id merchant's transaction ID for the payment
* @param coin_pub which public key was this payment about
* @param deposit_value amount contributed by this coin in total
@@ -1926,7 +1926,7 @@ handle_transaction_data (void *cls,
const struct TALER_MerchantPublicKeyP *merchant_pub,
const struct GNUNET_HashCode *h_wire,
struct GNUNET_TIME_Absolute exec_time,
- const struct GNUNET_HashCode *h_contract,
+ const struct GNUNET_HashCode *h_proposal_data,
uint64_t transaction_id,
const struct TALER_CoinSpendPublicKeyP *coin_pub,
const struct TALER_Amount *deposit_value,
@@ -1989,7 +1989,7 @@ handle_transaction_data (void *cls,
wdd = GNUNET_new (struct TEH_TrackTransferDetail);
wdd->deposit_value = *deposit_value;
wdd->deposit_fee = *deposit_fee;
- wdd->h_contract = *h_contract;
+ wdd->h_proposal_data = *h_proposal_data;
wdd->transaction_id = transaction_id;
wdd->coin_pub = *coin_pub;
GNUNET_CONTAINER_DLL_insert (ctx->wdd_head,
@@ -2080,9 +2080,9 @@ struct DepositWtidContext
struct MHD_Connection *connection;
/**
* Hash of the contract we are looking up.
*/
- struct GNUNET_HashCode h_contract;
+ struct GNUNET_HashCode h_proposal_data;
/**
* Hash of the wire transfer details we are looking up.
@@ -2150,7 +2150,7 @@ handle_wtid_data (void *cls,
else
{
ctx->res = TEH_RESPONSE_reply_track_transaction (ctx->connection,
- &ctx->h_contract,
+ &ctx->h_proposal_data,
&ctx->h_wire,
&ctx->coin_pub,
&coin_delta,
@@ -2167,7 +2167,7 @@ handle_wtid_data (void *cls,
* associated with the given deposit.
*
* @param connection the MHD connection to handle
- * @param h_contract hash of the contract
+ * @param h_proposal_data hash of the proposal data
* @param h_wire hash of the wire details
* @param coin_pub public key of the coin to link
* @param merchant_pub public key of the merchant
@@ -2176,7 +2176,7 @@ handle_wtid_data (void *cls,
*/
int
TEH_DB_execute_track_transaction (struct MHD_Connection *connection,
- const struct GNUNET_HashCode *h_contract,
+ const struct GNUNET_HashCode *h_proposal_data,
const struct GNUNET_HashCode *h_wire,
const struct TALER_CoinSpendPublicKeyP *coin_pub,
const struct TALER_MerchantPublicKeyP *merchant_pub,
@@ -2193,14 +2193,14 @@ TEH_DB_execute_track_transaction (struct MHD_Connection *connection,
TALER_EC_DB_SETUP_FAILED);
}
ctx.connection = connection;
- ctx.h_contract = *h_contract;
+ ctx.h_proposal_data = *h_proposal_data;
ctx.h_wire = *h_wire;
ctx.coin_pub = *coin_pub;
ctx.transaction_id = transaction_id;
ctx.res = GNUNET_SYSERR;
ret = TEH_plugin->wire_lookup_deposit_wtid (TEH_plugin->cls,
session,
- h_contract,
+ h_proposal_data,
h_wire,
coin_pub,
merchant_pub,
@@ -1915,7 +1915,7 @@ struct WtidTransactionContext
* @param h_wire hash of wire transfer details of the merchant (should be same for all callbacks with the same @e cls)
* @param exec_time execution time of the wire transfer (should be same for all callbacks with the same @e cls)
- * @param h_contract which contract was this payment about
+ * @param h_proposal_data which proposal was this payment about
* @param transaction_id merchant's transaction ID for the payment
* @param coin_pub which public key was this payment about
@@ -2080,9 +2080,9 @@ struct DepositWtidContext
struct MHD_Connection *connection;
/**
- * Hash of the contract we are looking up.
+ * Hash of the proposal data we are looking up.
*/